=================
Contributor Guide
=================

This guide is for contributors of the Kayobe project. It includes
information on proposing your first patch and how to participate in the
community.  It also covers responsibilities of core reviewers and the Project
Team Lead (PTL), and information about development processes.

We welcome everyone to join our project!

.. toctree::
   :maxdepth: 1

   contributing
   development
   vagrant
   manual
   automated
   testing
   release-notes
   releases
